Vulcan category demo

# Vulcan annotation tutorial

Provide category text in the box and press enter to compile.

Press compile to compile the selection and get the annotation object. Press decompile to re-select the dom from the annotation object.

To check whether this annotation object is completed. Use `category_object.validate(annotation object)`.

From the annotation object, use `category_object.querySelector(annotation object, query string)` to get a value down the tree.

Type a query string in the box.